/***********************************************************************/
/* Open Visualization Data Explorer                                    */
/* (C) Copyright IBM Corp. 1989,1999                                   */
/* ALL RIGHTS RESERVED                                                 */
/* This code licensed under the                                        */
/*    "IBM PUBLIC LICENSE - Open Visualization Data Explorer"          */
/***********************************************************************/
#define CIRCLE10PTS 10 
#define CIRCLE10TRS 8 
static Point points[CIRCLE10PTS] = {
 {  0.8090170026F,      0.5877852440F,      0.0000000000F },
 {  0.3090169728F,      0.9510565400F,      0.0000000000F },
 { -0.3090170324F,      0.9510564804F,      0.0000000000F },
 { -0.8090170622F,      0.5877851844F,      0.0000000000F },
 { -1.0000000000F,     -0.0000000874F,      0.0000000000F },
 { -0.8090169430F,     -0.5877853632F,      0.0000000000F },
 { -0.3090170920F,     -0.9510564804F,      0.0000000000F },
 {  0.3090171218F,     -0.9510564804F,      0.0000000000F },
 {  0.8090172410F,     -0.5877849460F,      0.0000000000F },
 {  1.0000000000F,      0.0000000000F,      0.0000000000F }
};
static Triangle triangles[] = {
 {   0,     1,     2 },
 {   0,     2,     3 },
 {   0,     3,     4 },
 {   0,     4,     5 },
 {   0,     5,     6 },
 {   0,     6,     7 },
 {   0,     7,     8 },
 {   0,     8,     9 }
};
